ttmltosrt
---------

Convert Timed Text Markup Language subtitles to SubRip format.

.. image:: https://travis-ci.org/RobbieClarken/ttmltosrt.svg
    :target: https://travis-ci.org/RobbieClarken/ttmltosrt


Installation
------------

::

    pip3 install ttmltosrt


Usage
-----

::

    ttmltosrt /path/to/input_file.ttml /path/to/output_file.srt
